CFileBuffer

Struct CFileBuffer 

pub struct CFileBuffer { /* private fields */ }
A C-compatible memory-backed file buffer.

This struct wraps a FILE* created via fmemopen, allowing FFI functions to write to a memory buffer that can then be read from Rust.

Implementations

Source

impl CFileBuffer

pub fn new(max_size: usize) -> Result<Self, &'static str>

Create a new CFileBuffer object with a buffer of max_size.

pub fn file(&mut self) -> CFilePtr<'_>

Get the raw FILE pointer wrapper. This mutably borrows self, ensuring no other borrows (like data()) can exist while this wrapper is alive.

pub fn data(&self) -> &[u8]

Flush the stream and return a slice over the data that has been written.

pub fn reset(&self) -> Result<(), &'static str>

Reset the position of the FILE* to the start of the file.